detector_cands_len: Get the Number of Candidate Segments

View source: R/RcppExports.R

detector_cands_lenR Documentation

Get the Number of Candidate Segments

Description

Returns the number of candidate changepoint segments currently tracked by the detector.

Usage

detector_cands_len(det_ptr)

Arguments

det_ptr

A "focus_detector" object created by detector_create().

Details

The FOCuS algorithm maintains a set of candidate segments that could potentially contain changepoints. This number grows with time but is controlled by the pruning parameters.

Value

Integer. Number of candidate segments.


focus documentation built on Sept. 17, 2026, 1:08 a.m.