detector_info_sn: Get the Cumulative Sum Statistic

View source: R/RcppExports.R

detector_info_snR Documentation

Get the Cumulative Sum Statistic

Description

Returns the current cumulative sum statistic maintained by the detector.

Usage

detector_info_sn(det_ptr)

Arguments

det_ptr

A "focus_detector" object created by detector_create().

Value

Numeric vector. Cumulative sum statistic. For univariate detectors, a scalar (length-1 vector). For multivariate detectors, a vector of length equal to the number of dimensions.


focus documentation built on Sept. 17, 2026, 1:08 a.m.