detector_pieces_len: Get number of candidate segments

View source: R/RcppExports.R

detector_pieces_lenR Documentation

Get number of candidate segments

Description

Returns the number of candidate changepoint segments currently tracked by the detector.

Usage

detector_pieces_len(info_ptr)

Arguments

info_ptr

External pointer to detector created by detector_create().

Details

The FOCuS algorithm maintains a set of candidate segments that could potentially contain changepoints. This number grows with time but is controlled by the pruning parameters.

Value

Integer. Number of candidate segments.


focus documentation built on March 30, 2026, 5:08 p.m.