detector_info_sn: Get cumulative sum statistic

View source: R/RcppExports.R

detector_info_snR Documentation

Get cumulative sum statistic

Description

Returns the current cumulative sum statistic maintained by the detector.

Usage

detector_info_sn(det_ptr)

Arguments

det_ptr

External pointer to detector created by detector_create().

Value

Numeric vector. Cumulative sum statistic. For univariate detectors, a scalar (length-1 vector). For multivariate detectors, a vector of length equal to the number of dimensions.


focus documentation built on June 13, 2026, 1:08 a.m.