detector_info_sn: Get cumulative sum statistic

View source: R/RcppExports.R

detector_info_snR Documentation

Get cumulative sum statistic

Description

Returns the current cumulative sum statistic maintained by the detector.

Usage

detector_info_sn(info_ptr)

Arguments

info_ptr

External pointer to detector created by detector_create().

Value

Numeric vector. Cumulative sum statistic. For univariate detectors, a scalar (length-1 vector). For multivariate detectors, a vector of length equal to the number of dimensions.


focus documentation built on March 30, 2026, 5:08 p.m.