| detector_info_sn | R Documentation |
Returns the current cumulative sum statistic maintained by the detector.
detector_info_sn(info_ptr)
info_ptr |
External pointer to detector created by
|
Numeric vector. Cumulative sum statistic. For univariate detectors, a scalar (length-1 vector). For multivariate detectors, a vector of length equal to the number of dimensions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.