| detector_pieces_len | R Documentation |
Returns the number of candidate changepoint segments currently tracked by the detector.
detector_pieces_len(info_ptr)
info_ptr |
External pointer to detector created by
|
The FOCuS algorithm maintains a set of candidate segments that could potentially contain changepoints. This number grows with time but is controlled by the pruning parameters.
Integer. Number of candidate segments.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.